pub struct InterestMap { /* private fields */ }Expand description
Interest map - tracks who is interested in what
Implementations
Sourceimpl InterestMap
impl InterestMap
Sourcepub fn register(&mut self, decl: InterestDeclaration)
pub fn register(&mut self, decl: InterestDeclaration)
Register interest
Sourcepub fn unregister(&mut self, node: NodeId, state_id: u64)
pub fn unregister(&mut self, node: NodeId, state_id: u64)
Unregister interest
Sourcepub fn interested_nodes(&self, state_id: u64) -> Vec<(NodeId, InterestLevel)>
pub fn interested_nodes(&self, state_id: u64) -> Vec<(NodeId, InterestLevel)>
Get all nodes interested in a state
Sourcepub fn nodes_with_interest(
&self,
state_id: u64,
min_level: InterestLevel,
) -> Vec<NodeId>
pub fn nodes_with_interest( &self, state_id: u64, min_level: InterestLevel, ) -> Vec<NodeId>
Get nodes with at least a certain interest level
Sourcepub fn node_states(&self, node: NodeId) -> Vec<u64>
pub fn node_states(&self, node: NodeId) -> Vec<u64>
Get all states a node is interested in
Sourcepub fn get_interest(&self, node: NodeId, state_id: u64) -> InterestLevel
pub fn get_interest(&self, node: NodeId, state_id: u64) -> InterestLevel
Get interest level for a specific node and state
Sourcepub fn interest_count(&self, state_id: u64) -> usize
pub fn interest_count(&self, state_id: u64) -> usize
Count interested nodes for a state
Sourcepub fn remove_node(&mut self, node: NodeId)
pub fn remove_node(&mut self, node: NodeId)
Remove a node entirely (they disconnected)